#ifndef Application_h
#define Application_h

// $Id: Application.h,v 1.10 2013/03/21 16:18:19 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "CommandLineParser.h"
#include "Config.h"
#include "Counter.h"
#include "ImageRecord.h"

class ImageRecordList;
class MainWindow;

/*!
\class  Application
\brief  Main Window singleton object
*/

class Application: public BaseApplication, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! command line help
    static void usage( void );

    //! constructor
    Application( CommandLineArguments );

    //! destructor
    ~Application( void );

    //! application manager
    virtual void initApplicationManager( void );

    //! create all widgets
    virtual bool realizeWidget( void );

    //! file list
    ImageRecordList& recentImages( void ) const
    { return *recentImages_; }

    //! retrieve MainWindow singleton
    MainWindow& mainWindow( void ) const
    { return *mainWindow_; }

    //!@name actions
    //@{

    //! open
    QAction& openAction( void ) const
    { return *openAction_; }

    //! reload
    QAction& reloadAction( void ) const
    { return *reloadAction_; }

    //! save
    QAction& saveAction( void ) const
    { return *saveAction_; }

    //! import
    QAction& importAction( void ) const
    { return *importAction_; }

    //! export
    QAction& exportAction( void ) const
    { return *exportAction_; }

    //@}

    public slots:

    //! open
    void open( ImageRecord );

    protected slots:

    //! about
    virtual void _about( void )
    { BaseApplication::_about( "Graphscan", VERSION, BUILD_TIMESTAMP ); }

    //! configuration
    virtual void _configuration( void );

    //! open
    void _open( void );

    //! save
    void _save( void );

    //! reload
    void _reload( void );

    //! exit safely
    void _exit( void );

    //! open data
    void _import( void );

    //! export data
    void _export( void );

    //! process request from application manager
    virtual bool _processCommand( SERVER::ServerCommand );

    //! about to quit
    virtual void _aboutToQuit( void );

    protected:

    //! install actions
    void _installActions( void );

    private:

    //! recent files
    ImageRecordList* recentImages_;

    //! main window entry selection frame
    MainWindow* mainWindow_;

    //!@name actions
    //@{

    //! open
    QAction* openAction_;

    //! save
    QAction* saveAction_;

    //! reload
    QAction* reloadAction_;

    //! import action
    QAction* importAction_;

    //! export action
    QAction* exportAction_;

    //@}

};

#endif
