// $Id: DataSetWidget.cpp,v 1.3 2013/03/12 08:47:46 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
****************************************************************************/

#include "DataSetWidget.h"
#include "IconEngine.h"
#include "Icons.h"

#include <QStringList>
#include <QLayout>
#include <QLabel>

//______________________________________________________________________________
DataSetWidget::DataSetWidget( QWidget* parent ):
    QWidget( parent ),
    Counter( "DataSetWidget" ),
    locked_( true )
{

    Debug::Throw( "DataSetWidget::DataSetWidget" );
    QHBoxLayout* layout( new QHBoxLayout() );
    layout->setSpacing(0);
    layout->setMargin(0);
    setLayout( layout );

    QLabel* label;
    layout->addWidget( label = new QLabel( tr( "Marker set:" ), this ) );
    layout->addWidget( combobox_ = new QComboBox( this ) );
    label->setBuddy( combobox_ );

    combobox_->setSizeAdjustPolicy( QComboBox::AdjustToContents );
    combobox_->setDuplicatesEnabled( false );
    connect( combobox_, SIGNAL( currentIndexChanged( int ) ), SLOT( _indexChanged( int ) ) );

    layout->addWidget( addButton_ = new QToolButton( this ) );
    addButton_->setAutoRaise( true );
    addButton_->setToolTip( tr( "Add Data Set" ) );
    addButton_->setIcon( IconEngine::get( ICONS::ADD ) );
    connect( addButton_, SIGNAL( clicked() ), SIGNAL( dataSetAdded( void ) ) );

    layout->addWidget( removeButton_ = new QToolButton( this ) );
    removeButton_->setAutoRaise( true );
    removeButton_->setToolTip( tr( "Remove Data Set" ) );
    removeButton_->setIcon( IconEngine::get( ICONS::REMOVE ) );
    connect( removeButton_, SIGNAL( clicked() ), SIGNAL( dataSetRemoved( void ) ) );

    layout->addStretch( 1 );
}

//______________________________________________________________________________
void DataSetWidget::setCollection( const RefPoint::Collection& collection )
{

    Debug::Throw( "DataSetWidget::setCollection" );

    locked_ = true;

    QStringList items;
    for( int index = 0; index < (int) collection.size(); index++ )
    {
        const QString buffer = QString( tr( "Set %1" ) ).arg( index+1 );
        items << buffer;
    }

    combobox_->clear();
    combobox_->addItems( items );

    removeButton_->setEnabled( collection.size() > 1 );
    locked_ = false;

}
