#ifndef _ImageRecordModel_h_
#define _ImageRecordModel_h_

// $Id: ImageRecordModel.h,v 1.7 2013/03/15 16:32:25 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "ImageRecord.h"
#include "ListModel.h"

#include <QStringList>

//! qlistview for object counters
class ImageRecordModel: public ListModel<ImageRecord>, public Counter
{

    Q_OBJECT

    public:

    //! column type enumeration
    enum ColumnType {
        FILE,
        PATH,
        TIME
    };

    //! constructor
    ImageRecordModel( QObject* = 0 );

    //!@name methods reimplemented from base class
    //@{

    //! flags
    virtual Qt::ItemFlags flags( const QModelIndex& ) const;

    // return data for a given index
    virtual QVariant data( const QModelIndex&, int ) const;

    //! header data
    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;

    //! number of columns for a given index
    virtual int columnCount( const QModelIndex& = QModelIndex() ) const;

    //! column matching given name, if any
    virtual int findColumn( const QString& ) const;

    //@}

    protected:

    //! sort
    virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder );

    private:

    //! used to sort Counters
    class SortFTor: public ItemModel::SortFTor
    {

        public:

        //! constructor
        SortFTor( const int& type, Qt::SortOrder order, const QStringList& column_titles ):
            ItemModel::SortFTor( type, order ),
            columnTitles_( column_titles )
        {}

        //! prediction
        bool operator() ( ImageRecord, ImageRecord ) const;

        private:

        // column titles
        QStringList columnTitles_;

    };

    //! update columns
    void _updateColumns( const ValueType& );;

    //! column titles
    QStringList columnTitles_;

};

#endif
