#ifndef ImportImageDialog_h
#define ImportImageDialog_h

// $Id: ImportImageDialog.h,v 1.4 2013/03/15 16:32:25 hupereir Exp $

/******************************************************************************
 *
 * Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
 *
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY;  without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * software; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA   02111-1307 USA
 *
 *
 *******************************************************************************/

#include "CustomDialog.h"
#include "File.h"

#include <QRadioButton>

class TextEditor;

class ImportImageDialog: public CustomDialog
{

    Q_OBJECT
    
    public:

    //! mode
    enum Mode
    {
        REPLACE_CURRENT = 1<<0,
        REPLACE_EXISTING = 1<<1,
        CREATE = 1<<2,
        ANY = REPLACE_CURRENT | REPLACE_EXISTING | CREATE
    };

    //! constructor
    ImportImageDialog( QWidget*, const File&, const unsigned int mask = ANY );

    //! destructor
    virtual ~ImportImageDialog( void )
    {}

    //! mode
    void setMode( Mode mode )
    {
        switch( mode )
        {
            case REPLACE_CURRENT: replaceCurrentCheckBox_->setChecked( true ); break;
            case REPLACE_EXISTING: replaceExistingCheckBox_->setChecked( true ); break;
            case CREATE: createCheckBox_->setChecked( true ); break;
            default: break;
        }
    }

    //! mode
    Mode mode( void ) const
    {
        if( replaceCurrentCheckBox_->isChecked() ) return REPLACE_CURRENT;
        else if( replaceExistingCheckBox_->isChecked() ) return REPLACE_EXISTING;
        else if( createCheckBox_->isChecked() ) return CREATE;
        else return CREATE;
    }

    private:

    //!@name checkboxes
    //@{
    QRadioButton* replaceCurrentCheckBox_;
    QRadioButton* replaceExistingCheckBox_;
    QRadioButton* createCheckBox_;
    //@}

};

#endif
