#ifndef NotificationWidget_h
#define NotificationWidget_h

// $Id: NotificationWidget.h,v 1.5 2013/02/14 09:02:46 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include <QLabel>

#include "Counter.h"

#include <QPaintEvent>
#include <QPropertyAnimation>
#include <QBasicTimer>
#include <QTimerEvent>

class NotificationWidget: public QLabel, public Counter
{

    Q_OBJECT
    Q_PROPERTY( qreal opacity READ opacity WRITE setOpacity )

    public:

    //! constructor
    NotificationWidget( QWidget* );

    //! destructor
    virtual ~NotificationWidget( void )
    {}

    //! set text
    virtual void setText( const QString& );

    //! clear
    virtual void clear( void )
    { hide(); }

    //! show
    virtual void show( void );

    //! hide
    virtual void hide( void );

    //! opacity
    int opacity( void ) const
    { return opacity_; }

    //! opacity
    virtual void setOpacity( int );

    protected:

    //! paint event
    void paintEvent( QPaintEvent* );

    //! timer event
    void timerEvent( QTimerEvent* );

    private slots:

    void _updateConfiguration( void );

    private:

    //! enable state
    bool enabled_;

    //! auto hide
    bool autoHide_;

    //! auto hide delay
    int autoHideDelay_;

    //! autohide timer
    QBasicTimer timer_;

    //! true if animated
    bool isAnimated_;

    //! fade in/fade out animation
    QPropertyAnimation animation_;

    //! opacity
    int opacity_;

};

#endif
