#ifndef PrintListDialog_h
#define PrintListDialog_h

// $Id: PrintListDialog.h,v 1.7 2013/02/14 09:02:46 hupereir Exp $

/******************************************************************************
 *
 * Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
 *
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY;  without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * software; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA   02111-1307 USA
 *
 *
 *******************************************************************************/

#include "CustomDialog.h"
#include "RefPoint.h"

#include <QCheckBox>
#include <QComboBox>
#include <QGroupBox>
#include <QLayout>
#include <QToolButton>

#include <QList>
#include <QStringList>

class TextEditor;

class PrintListDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //! format
    enum Format
    {
        FORMAT_RAW,
        FORMAT_LATEX,
        FORMAT_C
    };

    //! constructor
    PrintListDialog( QWidget* );

    //! destructor
    virtual ~PrintListDialog( void )
    {}

    //! set ref points
    void setCollection( const RefPoint::Collection&, int = -1 );

    //! format tool button
    QToolButton& formatToolButton( void ) const
    { return *formatToolButton_; }

    public slots:

    //! selection changed
    void updateText( void );

    protected slots:

    //! save format
    void _saveFormat( void );

    protected:

    //! print data set
    QString _printDataSet( int ) const;

    //! print data set
    QString _printDataSet( const RefPoint::List&, const QString& = QString() ) const;

    //! print data set
    QString _printDataSetRaw( const RefPoint::List&, const QString& = QString() ) const;

    //! print data set
    QString _printDataSetLatex( const RefPoint::List&, const QString& = QString() ) const;

    //! print data set
    QString _printDataSetC( const RefPoint::List&, const QString& = QString() ) const;

    //! print array
    QString _printArray( const QString&, const QStringList& ) const;

    //! var name
    QString _varName( const QString& var, const QString& name ) const
    { return name.isEmpty() ? var : var + "_" + name; }

    //! columns
    unsigned int _columns( const RefPoint::List& ) const;

    //! max length in array
    int _maxLength( const QStringList& ) const;

    //! normalize
    void _normalize( QStringList& ) const;

    private:

    class RefPointString: public Counter
    {

        public:

        //! constructor
        RefPointString( void ):
            Counter( "PrintListDialog::RefPointString" )
        {}

        //! set ref point
        RefPointString& set( const RefPoint&, const QString& localFormat = QString(), const QString& errorFormat = QString() );

        //!@name accessors
        //@{
        const QString& x( void ) const { return x_; }
        const QString& xStatPlus( void ) const { return xStatPlus_; }
        const QString& xStatMinus( void ) const { return xStatMinus_; }
        const QString& xSystPlus( void ) const { return xSystPlus_; }
        const QString& xSystMinus( void ) const { return xSystMinus_; }

        const QString& y( void ) const { return y_; }
        const QString& yStatPlus( void ) const { return yStatPlus_; }
        const QString& yStatMinus( void ) const { return yStatMinus_; }
        const QString& ySystPlus( void ) const { return ySystPlus_; }
        const QString& ySystMinus( void ) const { return ySystMinus_; }
        //@}

        protected:

        //! formated string
        QString _string( const double& value, const QString& format ) const;

        private:

        QString x_;
        QString xStatPlus_;
        QString xStatMinus_;
        QString xSystPlus_;
        QString xSystMinus_;

        QString y_;
        QString yStatPlus_;
        QString yStatMinus_;
        QString ySystPlus_;
        QString ySystMinus_;

    };

    class RefPointStringList: public QList<RefPointString>, public Counter
    {

        public:

        //! constructor
        RefPointStringList( void ):
            Counter( "PrintListDialog::RefPointStringList" )
        {}

        //! constructor
        RefPointStringList( const RefPoint::List&, const QString& localFormat = QString(), const QString& errorFormat = QString() );

    };

    enum Columns
    {
        COLUMNS_NONE = 0,
        COLUMNS_X = 1<<0,
        COLUMNS_X_STAT = 1<<1,
        COLUMNS_X_SYST = 1<<2,
        COLUMNS_Y = 1<<3,
        COLUMNS_Y_STAT = 1<<4,
        COLUMNS_Y_SYST = 1<<5,
        COLUMNS_X_ALL = COLUMNS_X | COLUMNS_X_STAT | COLUMNS_X_SYST,
        COLUMNS_Y_ALL = COLUMNS_Y | COLUMNS_Y_STAT | COLUMNS_Y_SYST,
        COLUMNS_ALL = COLUMNS_X_ALL | COLUMNS_Y_ALL
    };


    //! main grid layout
    QGridLayout* gridLayout_;

    //! format container
    QWidget* formatContainer_;

    //! format combobox
    QComboBox* formatComboBox_;

    //! format tool button
    QToolButton* formatToolButton_;

    //! checkbox container
    QWidget* checkBoxContainer_;

    //! vertical layout of for checkboxes
    QVBoxLayout* checkBoxLayout_;

    //! list of checkboxes for dataset selection
    typedef QList<QCheckBox*> CheckBoxList;
    CheckBoxList checkBoxes_;

    //! editor
    TextEditor* editor_;

    //! collection
    RefPoint::Collection collection_;

    //! format
    Format format_;

};

#endif
