#ifndef RefPointListWidget_h
#define RefPointListWidget_h

// $Id: RefPointListWidget.h,v 1.15 2013/03/22 09:41:40 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "DataSetWidget.h"
#include "RefPointModel.h"
#include "TreeView.h"

#include <QAction>
#include <QWidget>

class RefPointListWidget: public QWidget
{

    Q_OBJECT

    public:

    //! constructor
    RefPointListWidget( QWidget* = 0L );

    //!@name accessors
    //@{

    //! points (for current dataSet)
    RefPoint::List get( void ) const;

    //! points (from collection)
    RefPoint::Collection collection( void ) const;

    //! has selection
    bool hasSelection( void ) const;

    //! selection points
    RefPoint::List selection( void ) const;

    //! dataset index
    int dataSetIndex( void ) const
    { return dataSetIndex_; }

    //! true if current dataset contains point
    bool contains( const RefPoint& point ) const
    { return model_.index( point ).isValid(); }

    //@}

    //!@name modifiers
    //@{

    //! set collection
    void setCollection( const RefPoint::Collection& );

    //! add data set
    void addDataSet( const RefPoint::List& );

    //! dataSet index
    void setDataSetIndex( int );

    //! clear
    void clear( void );

    //! add
    void add( const RefPoint& );

    //! remove
    void remove( const RefPoint& );

    //! copy
    void copy( const RefPoint& );

    //! paste
    const RefPoint& clipboard( void ) const
    { return clipboard_; }

    //! clear selection
    void clearSelection( void );

    //! select point
    bool select( const RefPoint& );

    //! replace two ref points
    bool replace( const RefPoint&, const RefPoint& );

    //! validity
    void setRefPointsValid( bool value )
    { model_.setRefPointsValid( value ); }

    //@}

    //!@name actions
    //@{

    QAction& moveUpAction( void ) const
    { return *moveUpAction_; }

    QAction& moveDownAction( void ) const
    { return *moveDownAction_; }

    QAction& sortAction( void ) const
    { return *sortAction_; }

    QAction& removeAction( void ) const
    { return *removeAction_; }

    QAction& printAction( void ) const
    { return *printAction_; }

    QAction& printAllAction( void ) const
    { return *printAllAction_; }

    QAction& editErrorsAction( void ) const
    { return *editErrorsAction_; }

    QAction& defaultErrorsAction( void ) const
    { return *defaultErrorsAction_; }

    QAction& defaultErrorsSystAction( void ) const
    { return *defaultErrorsSystAction_; }

    QAction& refPointFormatAction( void ) const
    { return *refPointFormatAction_; }

    //@}

    signals:

    //! emit when modified
    void modified();

    //! emit when selection is changed
    void selectionChanged( void );

    //! emit when selection is removed
    void selectionRemoved( const RefPoint::List& );

    //! emit when error edition is requested
    void errorsEdited( RefPoint );

    //! emit when default errors has to be added
    void defaultErrorsAdded( RefPoint );

    //! syst errors to be added
    void defaultErrorsSystAdded( RefPoint );

    //! clipboard
    void clipboardAvailable( bool );

    // format configuration
    void refPointFormatChanged( void );

    public slots:

    //! update actions
    void updateActions( void );

    protected slots:

    //! move selection up
    void _moveUp( void );

    //! move selection down
    void _moveDown( void );

    //! sort
    void _sort( void );

    //! remove
    void _remove( void );

    //! print
    void _print( void );

    //! print
    void _printAll( void );

    //! edit errors
    void _editErrors( void );

    //! add default errors
    void _addDefaultErrors( void );

    //! add default syst errors
    void _addDefaultErrorsSyst( void );

    //! add data set
    void _addDataSet( void );

    //! remove data set
    void _removeDataSet( void );

    //! select data set
    void _selectDataSet( int );

    //! reference point format configuration
    void _configureRefPointFormat( void );

    //! update context menu
    void _updateContextMenu( const QPoint& );

    private slots:

    //! update configuration
    void _updateConfiguration( void );

    private:

    //! install actions
    void _installActions( void );

    //! Ref point collection
    RefPoint::Collection dataSets_;

    //! copied point
    RefPoint clipboard_;

    //! index
    int dataSetIndex_;

    //!@name actions
    //@{

    QAction* moveUpAction_;
    QAction* moveDownAction_;
    QAction* sortAction_;
    QAction* removeAction_;
    QAction* printAction_;
    QAction* printAllAction_;
    QAction* editErrorsAction_;
    QAction* defaultErrorsAction_;
    QAction* defaultErrorsSystAction_;
    QAction* refPointFormatAction_;

    //@}

    //! model
    RefPointModel model_;

    //! dataset widget
    DataSetWidget* dataSetWidget_;

    //! list
    TreeView* list_;

};

#endif
