#ifndef RefPointModel_h
#define RefPointModel_h

// $Id: RefPointModel.h,v 1.8 2013/03/22 09:41:40 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "RefPoint.h"
#include "ListModel.h"

class RefPointModel: public ListModel<RefPoint>
{

    Q_OBJECT

    public:

    //! number of columns
    enum { nColumns = 7 };

    enum ColumnType
    {
        INDEX,
        GLOBAL,
        LOCAL,
        ERRORS_X,
        ERRORS_Y,
        ERRORS_SYST_X,
        ERRORS_SYST_Y
    };

    //! constructor
    RefPointModel( QObject* parent = 0 ):
        ListModel<RefPoint>( parent ),
        refPointsValid_( true )
    {}

    //!@name methods reimplemented from base class
    //@{

    // return data for a given index
    virtual QVariant data( const QModelIndex&, int ) const;

    //! header data
    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;

    //! number of columns for a given index
    virtual int columnCount( const QModelIndex& = QModelIndex() ) const
    { return nColumns; }

    //@}

    //! local format
    void setGlobalFormat( const QString& );

    //! local format
    void setLocalFormat( const QString& );

    //! local format
    void setErrorFormat( const QString& );

    //! reference points valid
    void setRefPointsValid( bool value )
    { refPointsValid_ = value; }

    protected:

    //! sort
    virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder )
    {}

    //! convert error to string
    QString error( const RefPoint::Error&, const double& ) const;

    private:

    //! column titles
    static const QString columnTitles_[ nColumns ];

    //! global number format
    QString globalFormat_;

    //! local number format
    QString localFormat_;

    //! error number format
    QString errorFormat_;

    //! true if reference points are valid
    bool refPointsValid_;

};

#endif
