// $Id: UndoCommand.cpp,v 1.4 2013/01/24 16:21:14 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "UndoCommand.h"

//____________________________________________________________________
void MarkerAddedCommand::undo( void )
{ if( _parent() ) _parent().data()->removePoint( _dataSetIndex(), point_ ); }

//____________________________________________________________________
void MarkerAddedCommand::redo( void )
{ if( _parent() ) _parent().data()->addPoint( _dataSetIndex(), point_ ); }

//____________________________________________________________________
void MarkerRemovedCommand::undo( void )
{ if( _parent() ) _parent().data()->addPoint( _dataSetIndex(), point_ ); }

//____________________________________________________________________
void MarkerRemovedCommand::redo( void )
{ if( _parent() ) _parent().data()->removePoint( _dataSetIndex(), point_ ); }

//____________________________________________________________________
void MarkerChangedCommand::undo( void )
{ if( _parent() ) _parent().data()->replacePoint( _dataSetIndex(), destination_, source_ ); }

//____________________________________________________________________
void MarkerChangedCommand::redo( void )
{ if( _parent() ) _parent().data()->replacePoint( _dataSetIndex(), source_, destination_ ); }

//____________________________________________________________________
bool MarkerChangedCommand::mergeWith( const QUndoCommand* command )
{
    const MarkerChangedCommand* other( static_cast<const MarkerChangedCommand*>( command ) );

    if( !_canMerge( other ) ) return false;
    if( _dataSetIndex() == other->_dataSetIndex() && destination_ == other->source_ )
    {
        setTime( other->time() );
        destination_ = other->destination_;
        return true;

    } else return false;
}

//____________________________________________________________________
void RefPointAddedCommand::undo( void )
{ if( _parent() ) _parent().data()->removeReferencePoint( _index() ); }

//____________________________________________________________________
void RefPointAddedCommand::redo( void )
{ if( _parent() ) _parent().data()->updateReferencePoint( _index(), point_ ); }

//____________________________________________________________________
void RefPointRemovedCommand::undo( void )
{ if( _parent() ) _parent().data()->updateReferencePoint( _index(), point_ ); }

//____________________________________________________________________
void RefPointRemovedCommand::redo( void )
{ if( _parent() ) _parent().data()->removeReferencePoint( _index() ); }

//____________________________________________________________________
void RefPointChangedCommand::undo( void )
{ if( _parent() ) _parent().data()->updateReferencePoint( _index(), source_ ); }

//____________________________________________________________________
void RefPointChangedCommand::redo( void )
{ if( _parent() ) _parent().data()->updateReferencePoint( _index(), destination_ ); }

//____________________________________________________________________
bool RefPointChangedCommand::mergeWith( const QUndoCommand* command )
{
    const RefPointChangedCommand* other( static_cast<const RefPointChangedCommand*>( command ) );

    if( !_canMerge( other ) ) return false;
    if( _index() == other->_index() && destination_ == other->source_ )
    {
        setTime( other->time() );
        destination_ = other->destination_;
        return true;

    } else return false;
}
