#ifndef ZoomWidget_h
#define ZoomWidget_h

// $Id: ZoomWidget.h,v 1.11 2013/02/14 09:02:46 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
****************************************************************************/

#include "Counter.h"
#include "Debug.h"

#include <QAction>
#include <QWidget>

// forward declaration
class CustomComboBox;

class ZoomWidget: public QWidget, public Counter
{

    Q_OBJECT

    public:

    //! constructor
    ZoomWidget( QWidget* = 0L );

    //! destructor
    virtual ~ZoomWidget( void )
    {}

    //! zoom mode
    enum Mode
    {
        FitWidth,
        FitHeight,
        FitPage,
        Fixed
    };

    //! mode
    Mode mode( void ) const
    { return mode_; }

    //! factor
    double factor( void ) const
    { return factor_; }

    //! event filter
    bool eventFilter( QObject*, QEvent* );

    //!@name actions
    //@{

    QAction& zoomInAction( void )
    { return *zoomInAction_; }

    QAction& zoomOutAction( void )
    { return *zoomOutAction_; }

    //@}

    public slots:

    //! change "real" factor
    void realFactorChanged( double );

    signals:

    //! modified
    void modified( ZoomWidget::Mode, double );

    protected slots:

    //! zoom in
    void _zoomIn( int = 1 );

    //! zoom out
    void _zoomOut( int = 1 );

    //! setup items
    void _setupItems( bool forced = false );

    //! current item changed
    void _currentIndexChanged( const QString& );

    protected:

    //! change factor
    void _setFactor( double );

    //! return index of nearest fixed factor matching current
    int _findNearestFactor( double ) const;

    private slots:

    //! configuration
    void _updateConfiguration( void );

    private:

    //!@name actions
    //@{
    QAction* zoomInAction_;
    QAction* zoomOutAction_;
    //@}

    //! combobox
    CustomComboBox* combobox_;

    //! zoom mode
    Mode mode_;

    //! zoom factor
    double factor_;

    //! zoom factor
    double realFactor_;

    //! true when configured at least once
    bool configured_;

};

#endif
